abacusai.point_in_time_group_feature — AbacusAI documentation

# abacusai.point_in_time_group_feature

## Classes

`PointInTimeGroupFeature` | A point in time group feature

## Module Contents

class abacusai.point_in_time_group_feature.PointInTimeGroupFeature(client, name=None, expression=None, pitOperationType=None, pitOperationConfig=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A point in time group feature

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The name of the feature

    - expression (str) – SQL Aggregate expression which can convert a sequence of rows into a scalar value.

    - pitOperationType (str) – The operation used in point in time feature generation

    - pitOperationConfig (dict) – The configuration used as input to the operation type

  name
  expression
  pit_operation_type
  pit_operation_config
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict